pub enum Fit {
Stretch,
Letterbox {
pad: [u8; 4],
},
}Expand description
How a source is fit into the requested destination shape.
Variants
Stretch
Stretch the source (or source crop) to fill the whole destination.
Letterbox
Preserve the source aspect ratio, centring it in the destination and
padding the remainder with pad (RGBA — e.g. [114, 114, 114, 255] for
YOLO-style preprocessing).