ImageProcessor

Struct ImageProcessor 

pub struct ImageProcessor {
    pub cpu: Option<CPUProcessor>,
}
Image converter that uses available hardware acceleration or CPU as a fallback.

Fields

cpu: Option<CPUProcessor>

CPU-based image converter as a fallback. This is only None if the EDGEFIRST_DISABLE_CPU environment variable is set.

Implementations

Source

impl ImageProcessor

pub fn new() -> Result<Self>

Creates a new ImageProcessor instance, initializing available hardware converters based on the system capabilities and environment variables.

Examples
let image = include_bytes!("../../../testdata/zidane.jpg");
let img = TensorImage::load(image, Some(RGBA), None)?;
let mut converter = ImageProcessor::new()?;
let mut dst = TensorImage::new(640, 480, RGB, None)?;
converter.convert(&img, &mut dst, Rotation::None, Flip::None, Crop::default())?;