pub struct ImageProcessor {
pub cpu: Option<CPUProcessor>,
}Expand description
Image converter that uses available hardware acceleration or CPU as a fallback.
Fields
cpu: Option<CPUProcessor>CPU-based image converter as a fallback. This is only None if the EDGEFIRST_DISABLE_CPU environment variable is set.
Implementations
Sourceimpl ImageProcessor
impl ImageProcessor
Sourcepub fn new() -> Result<Self>
pub fn new() -> Result<Self>
Creates a new ImageProcessor instance, initializing available
hardware converters based on the system capabilities and environment
variables.
Examples
let image = include_bytes!("../../../testdata/zidane.jpg");
let img = TensorImage::load(image, Some(RGBA), None)?;
let mut converter = ImageProcessor::new()?;
let mut dst = TensorImage::new(640, 480, RGB, None)?;
converter.convert(&img, &mut dst, Rotation::None, Flip::None, Crop::default())?;Trait Implementations
Sourceimpl Debug for ImageProcessor
impl Debug for ImageProcessor
Sourceimpl ImageProcessorTrait for ImageProcessor
impl ImageProcessorTrait for ImageProcessor
Sourcefn convert(
&mut self,
src: &TensorImage,
dst: &mut TensorImage,
rotation: Rotation,
flip: Flip,
crop: Crop,
) -> Result<()>
fn convert( &mut self, src: &TensorImage, dst: &mut TensorImage, rotation: Rotation, flip: Flip, crop: Crop, ) -> Result<()>
Converts the source image to the destination image format and size. The image is cropped first, then flipped, then rotated
Prefer hardware accelerators when available, falling back to CPU if necessary.
Sourcefn convert_ref(
&mut self,
src: &TensorImage,
dst: &mut TensorImageRef<'_>,
rotation: Rotation,
flip: Flip,
crop: Crop,
) -> Result<()>
fn convert_ref( &mut self, src: &TensorImage, dst: &mut TensorImageRef<'_>, rotation: Rotation, flip: Flip, crop: Crop, ) -> Result<()>
Converts the source image to a borrowed destination tensor for zero-copy
preprocessing. Read more
fn render_to_image( &mut self, dst: &mut TensorImage, detect: &[DetectBox], segmentation: &[Segmentation], ) -> Result<()>
impl Send for ImageProcessor
impl Sync for ImageProcessor